@@ -25,9 +25,6 @@ Originally developed as part of the ACME_ protocol implementation.
 .. _ACME: https://pypi.python.org/pypi/acme
 
 """
-import sys
-import warnings
-
 # flake8: noqa
 from josepy.b64 import (
     b64decode,
@@ -68,6 +65,9 @@ from josepy.jwa import (
     RS256,
     RS384,
     RS512,
+    ES256,
+    ES384,
+    ES512,
 )
 
 from josepy.jwk import (
@@ -87,10 +87,3 @@ from josepy.util import (
     ComparableRSAKey,
     ImmutableMap,
 )
-
-if sys.version_info[:2] == (2, 7):
-    warnings.warn(
-            "Python 2.7 support will be dropped in the next release of "
-            "josepy. Please upgrade your Python version.",
-            DeprecationWarning,
-    )
